<?php

namespace Litecms\Bid\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Bid\Interfaces\BidRepositoryInterface;

class BidPublicController extends BaseController
{
    // use BidWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Bid\Interfaces\BidRepositoryInterface $bid
     *
     * @return type
     */
    public function __construct(BidRepositoryInterface $bid)
    {
        $this->repository = $bid;
        parent::__construct();
    }

    /**
     * Show bid's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $bids = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$bid::$bid.names'))
            ->view('$bid::public.bid.index')
            ->data(compact('$bids'))
            ->output();
    }

    /**
     * Show bid's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $bids = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$bid::$bid.names'))
            ->view('$bid::public.bid.index')
            ->data(compact('$bids'))
            ->output();
    }

    /**
     * Show bid.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $bid = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$bid->name . trans('$bid::$bid.name'))
            ->view('$bid::public.bid.show')
            ->data(compact('$bid'))
            ->output();
    }

}
