<?php

namespace Litecms\Bid\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Bid\Models\Bid;

class BidPolicy
{

    /**
     * Determine if the given user can view the bid.
     *
     * @param UserPolicy $user
     * @param Bid $bid
     *
     * @return bool
     */
    public function view(UserPolicy $user, Bid $bid)
    {
        if ($user->canDo('bid.bid.view') && $user->isAdmin()) {
            return true;
        }

        return $bid->user_id == user_id() && $bid->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bid.
     *
     * @param UserPolicy $user
     * @param Bid $bid
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bid.bid.create');
    }

    /**
     * Determine if the given user can update the given bid.
     *
     * @param UserPolicy $user
     * @param Bid $bid
     *
     * @return bool
     */
    public function update(UserPolicy $user, Bid $bid)
    {
        if ($user->canDo('bid.bid.edit') && $user->isAdmin()) {
            return true;
        }

        return $bid->user_id == user_id() && $bid->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bid.
     *
     * @param UserPolicy $user
     * @param Bid $bid
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Bid $bid)
    {
        return $bid->user_id == user_id() && $bid->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bid.
     *
     * @param UserPolicy $user
     * @param Bid $bid
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Bid $bid)
    {
        if ($user->canDo('bid.bid.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bid.
     *
     * @param UserPolicy $user
     * @param Bid $bid
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Bid $bid)
    {
        if ($user->canDo('bid.bid.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
