<?php

namespace Litecms\Bid\Providers;

use Illuminate\Support\ServiceProvider;

class BidServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'bid');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'bid');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.bid', function ($app) {
            return $this->app->make('Litecms\Bid\Bid');
        });

                // Bind Bid to repository
        $this->app->bind(
            'Litecms\Bid\Interfaces\BidRepositoryInterface',
            \Litecms\Bid\Repositories\Eloquent\BidRepository::class
        );

        $this->app->register(\Litecms\Bid\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Bid\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Bid\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.bid'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/bid.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/bid')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/bid')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
